@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ from tencentcloud.mps.v20190612 import models
 class MpsClient(AbstractClient):
     _apiVersion = '2019-06-12'
     _endpoint = 'mps.tencentcloudapi.com'
+    _service = 'mps'
 
 
     def CreateAIAnalysisTemplate(self, request):
@@ -35,7 +36,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAIAnalysisTemplate", params)
+            headers = request.headers
+            body = self.call("CreateAIAnalysisTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAIAnalysisTemplateResponse()
@@ -63,7 +65,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAIRecognitionTemplate", params)
+            headers = request.headers
+            body = self.call("CreateAIRecognitionTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAIRecognitionTemplateResponse()
@@ -91,7 +94,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAdaptiveDynamicStreamingTemplate", params)
+            headers = request.headers
+            body = self.call("CreateAdaptiveDynamicStreamingTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAdaptiveDynamicStreamingTemplateResponse()
@@ -119,7 +123,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAnimatedGraphicsTemplate", params)
+            headers = request.headers
+            body = self.call("CreateAnimatedGraphicsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAnimatedGraphicsTemplateResponse()
@@ -138,7 +143,7 @@ class MpsClient(AbstractClient):
 
 
     def CreateContentReviewTemplate(self, request):
-        """创建用户自定义内容审核模板，数量上限：50。
+        """创建用户自定义内容智能识别模板，数量上限：50。
 
         :param request: Request instance for CreateContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreateContentReviewTemplateRequest`
@@ -147,7 +152,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateContentReviewTemplate", params)
+            headers = request.headers
+            body = self.call("CreateContentReviewTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateContentReviewTemplateResponse()
@@ -175,7 +181,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateImageSpriteTemplate", params)
+            headers = request.headers
+            body = self.call("CreateImageSpriteTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateImageSpriteTemplateResponse()
@@ -194,7 +201,7 @@ class MpsClient(AbstractClient):
 
 
     def CreatePersonSample(self, request):
-        """该接口用于创建人物样本，用于通过人脸识别等技术，进行内容识别、内容审核等视频处理。
+        """该接口用于创建素材样本，用于通过五官定位等技术，进行内容识别、内容不适宜等视频处理。
 
         :param request: Request instance for CreatePersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreatePersonSampleRequest`
@@ -203,7 +210,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePersonSample", params)
+            headers = request.headers
+            body = self.call("CreatePersonSample", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePersonSampleResponse()
@@ -231,7 +239,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSampleSnapshotTemplate", params)
+            headers = request.headers
+            body = self.call("CreateSampleSnapshotTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSampleSnapshotTemplateResponse()
@@ -259,7 +268,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSnapshotByTimeOffsetTemplate", params)
+            headers = request.headers
+            body = self.call("CreateSnapshotByTimeOffsetTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSnapshotByTimeOffsetTemplateResponse()
@@ -287,7 +297,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTranscodeTemplate", params)
+            headers = request.headers
+            body = self.call("CreateTranscodeTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTranscodeTemplateResponse()
@@ -315,7 +326,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateWatermarkTemplate", params)
+            headers = request.headers
+            body = self.call("CreateWatermarkTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateWatermarkTemplateResponse()
@@ -334,7 +346,7 @@ class MpsClient(AbstractClient):
 
 
     def CreateWordSamples(self, request):
-        """该接口用于批量创建关键词样本，样本用于通过OCR、ASR技术，进行内容审核、内容识别等视频处理。
+        """该接口用于批量创建关键词样本，样本用于通过OCR、ASR技术，进行不适宜内容识别、内容识别等视频处理。
 
         :param request: Request instance for CreateWordSamples.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreateWordSamplesRequest`
@@ -343,7 +355,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateWordSamples", params)
+            headers = request.headers
+            body = self.call("CreateWordSamples", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateWordSamplesResponse()
@@ -369,7 +382,7 @@ class MpsClient(AbstractClient):
         4. 对视频采样截图；
         5. 对视频截图雪碧图；
         6. 对视频转自适应码流；
-        7. 智能内容审核（鉴黄、鉴恐、鉴政）；
+        7. 智能内容审核（鉴黄、敏感信息检测）；
         8. 智能内容分析（标签、分类、封面、按帧标签）；
         9. 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
 
@@ -382,7 +395,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateWorkflow", params)
+            headers = request.headers
+            body = self.call("CreateWorkflow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateWorkflowResponse()
@@ -412,7 +426,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAIAnalysisTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteAIAnalysisTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAIAnalysisTemplateResponse()
@@ -440,7 +455,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAIRecognitionTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteAIRecognitionTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAIRecognitionTemplateResponse()
@@ -468,7 +484,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAdaptiveDynamicStreamingTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteAdaptiveDynamicStreamingTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAdaptiveDynamicStreamingTemplateResponse()
@@ -496,7 +513,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAnimatedGraphicsTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteAnimatedGraphicsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAnimatedGraphicsTemplateResponse()
@@ -515,7 +533,7 @@ class MpsClient(AbstractClient):
 
 
     def DeleteContentReviewTemplate(self, request):
-        """删除用户自定义内容审核模板。
+        """删除用户自定义内容智能识别模板。
 
         :param request: Request instance for DeleteContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.DeleteContentReviewTemplateRequest`
@@ -524,7 +542,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteContentReviewTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteContentReviewTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteContentReviewTemplateResponse()
@@ -552,7 +571,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteImageSpriteTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteImageSpriteTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteImageSpriteTemplateResponse()
@@ -571,7 +591,7 @@ class MpsClient(AbstractClient):
 
 
     def DeletePersonSample(self, request):
-        """该接口用于根据人物 ID，删除人物样本。
+        """该接口用于根据素材 ID，删除素材样本。
 
         :param request: Request instance for DeletePersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.DeletePersonSampleRequest`
@@ -580,7 +600,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePersonSample", params)
+            headers = request.headers
+            body = self.call("DeletePersonSample", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePersonSampleResponse()
@@ -608,7 +629,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSampleSnapshotTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSampleSnapshotTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSampleSnapshotTemplateResponse()
@@ -636,7 +658,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSnapshotByTimeOffsetTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSnapshotByTimeOffsetTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSnapshotByTimeOffsetTemplateResponse()
@@ -664,7 +687,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTranscodeTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteTranscodeTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTranscodeTemplateResponse()
@@ -692,7 +716,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteWatermarkTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteWatermarkTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteWatermarkTemplateResponse()
@@ -720,7 +745,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteWordSamples", params)
+            headers = request.headers
+            body = self.call("DeleteWordSamples", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteWordSamplesResponse()
@@ -748,7 +774,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteWorkflow", params)
+            headers = request.headers
+            body = self.call("DeleteWorkflow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteWorkflowResponse()
@@ -776,7 +803,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAIAnalysisTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeAIAnalysisTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAIAnalysisTemplatesResponse()
@@ -804,7 +832,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAIRecognitionTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeAIRecognitionTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAIRecognitionTemplatesResponse()
@@ -832,7 +861,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAdaptiveDynamicStreamingTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeAdaptiveDynamicStreamingTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAdaptiveDynamicStreamingTemplatesResponse()
@@ -860,7 +890,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAnimatedGraphicsTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeAnimatedGraphicsTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAnimatedGraphicsTemplatesResponse()
@@ -879,7 +910,7 @@ class MpsClient(AbstractClient):
 
 
     def DescribeContentReviewTemplates(self, request):
-        """根据内容审核模板唯一标识，获取内容审核模板详情列表。返回结果包含符合条件的所有用户自定义模板及系统预置内容审核模板。
+        """根据内容智能识别模板唯一标识，获取内容智能识别模板详情列表。返回结果包含符合条件的所有用户自定义模板及系统预置内容智能识别模板。
 
         :param request: Request instance for DescribeContentReviewTemplates.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribeContentReviewTemplatesRequest`
@@ -888,7 +919,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeContentReviewTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeContentReviewTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeContentReviewTemplatesResponse()
@@ -916,7 +948,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeImageSpriteTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeImageSpriteTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeImageSpriteTemplatesResponse()
@@ -944,7 +977,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMediaMetaData", params)
+            headers = request.headers
+            body = self.call("DescribeMediaMetaData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMediaMetaDataResponse()
@@ -963,7 +997,7 @@ class MpsClient(AbstractClient):
 
 
     def DescribePersonSamples(self, request):
-        """该接口用于查询人物样本信息，支持根据人物 ID、名称、标签，分页查询。
+        """该接口用于查询素材样本信息，支持根据素材 ID、名称、标签，分页查询。
 
         :param request: Request instance for DescribePersonSamples.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribePersonSamplesRequest`
@@ -972,7 +1006,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePersonSamples", params)
+            headers = request.headers
+            body = self.call("DescribePersonSamples", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePersonSamplesResponse()
@@ -1000,7 +1035,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSampleSnapshotTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeSampleSnapshotTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSampleSnapshotTemplatesResponse()
@@ -1028,7 +1064,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSnapshotByTimeOffsetTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeSnapshotByTimeOffsetTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSnapshotByTimeOffsetTemplatesResponse()
@@ -1056,7 +1093,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTaskDetail", params)
+            headers = request.headers
+            body = self.call("DescribeTaskDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTaskDetailResponse()
@@ -1086,7 +1124,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTasks", params)
+            headers = request.headers
+            body = self.call("DescribeTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTasksResponse()
@@ -1114,7 +1153,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTranscodeTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeTranscodeTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTranscodeTemplatesResponse()
@@ -1142,7 +1182,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeWatermarkTemplates", params)
+            headers = request.headers
+            body = self.call("DescribeWatermarkTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeWatermarkTemplatesResponse()
@@ -1170,7 +1211,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeWordSamples", params)
+            headers = request.headers
+            body = self.call("DescribeWordSamples", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeWordSamplesResponse()
@@ -1198,7 +1240,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeWorkflows", params)
+            headers = request.headers
+            body = self.call("DescribeWorkflows", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeWorkflowsResponse()
@@ -1226,7 +1269,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisableWorkflow", params)
+            headers = request.headers
+            body = self.call("DisableWorkflow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisableWorkflowResponse()
@@ -1258,7 +1302,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EditMedia", params)
+            headers = request.headers
+            body = self.call("EditMedia", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EditMediaResponse()
@@ -1286,7 +1331,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EnableWorkflow", params)
+            headers = request.headers
+            body = self.call("EnableWorkflow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EnableWorkflowResponse()
@@ -1314,7 +1360,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ExecuteFunction", params)
+            headers = request.headers
+            body = self.call("ExecuteFunction", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ExecuteFunctionResponse()
@@ -1334,7 +1381,6 @@ class MpsClient(AbstractClient):
 
     def ManageTask(self, request):
         """对已发起的任务进行管理。
-        > 注意：目前仅支持终止执行中的直播流处理任务。
 
         :param request: Request instance for ManageTask.
         :type request: :class:`tencentcloud.mps.v20190612.models.ManageTaskRequest`
@@ -1343,7 +1389,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ManageTask", params)
+            headers = request.headers
+            body = self.call("ManageTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ManageTaskResponse()
@@ -1373,7 +1420,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAIAnalysisTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyAIAnalysisTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAIAnalysisTemplateResponse()
@@ -1401,7 +1449,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAIRecognitionTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyAIRecognitionTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAIRecognitionTemplateResponse()
@@ -1429,7 +1478,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAdaptiveDynamicStreamingTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyAdaptiveDynamicStreamingTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAdaptiveDynamicStreamingTemplateResponse()
@@ -1457,7 +1507,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAnimatedGraphicsTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyAnimatedGraphicsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAnimatedGraphicsTemplateResponse()
@@ -1476,7 +1527,7 @@ class MpsClient(AbstractClient):
 
 
     def ModifyContentReviewTemplate(self, request):
-        """修改用户自定义内容审核模板。
+        """修改用户自定义内容智能识别模板。
 
         :param request: Request instance for ModifyContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.ModifyContentReviewTemplateRequest`
@@ -1485,7 +1536,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyContentReviewTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyContentReviewTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyContentReviewTemplateResponse()
@@ -1513,7 +1565,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyImageSpriteTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyImageSpriteTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyImageSpriteTemplateResponse()
@@ -1532,7 +1585,7 @@ class MpsClient(AbstractClient):
 
 
     def ModifyPersonSample(self, request):
-        """该接口用于根据人物 ID，修改人物样本信息，包括名称、描述的修改，以及人脸、标签的添加、删除、重置操作。人脸删除操作需保证至少剩余 1 张图片，否则，请使用重置操作。
+        """该接口用于根据素材 ID，修改素材样本信息，包括名称、描述的修改，以及五官、标签的添加、删除、重置操作。五官删除操作需保证至少剩余 1 张图片，否则，请使用重置操作。
 
         :param request: Request instance for ModifyPersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.ModifyPersonSampleRequest`
@@ -1541,7 +1594,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPersonSample", params)
+            headers = request.headers
+            body = self.call("ModifyPersonSample", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPersonSampleResponse()
@@ -1569,7 +1623,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySampleSnapshotTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySampleSnapshotTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySampleSnapshotTemplateResponse()
@@ -1597,7 +1652,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySnapshotByTimeOffsetTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySnapshotByTimeOffsetTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySnapshotByTimeOffsetTemplateResponse()
@@ -1625,7 +1681,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyTranscodeTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyTranscodeTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyTranscodeTemplateResponse()
@@ -1653,7 +1710,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyWatermarkTemplate", params)
+            headers = request.headers
+            body = self.call("ModifyWatermarkTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyWatermarkTemplateResponse()
@@ -1681,7 +1739,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyWordSample", params)
+            headers = request.headers
+            body = self.call("ModifyWordSample", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyWordSampleResponse()
@@ -1710,7 +1769,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ParseLiveStreamProcessNotification", params)
+            headers = request.headers
+            body = self.call("ParseLiveStreamProcessNotification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ParseLiveStreamProcessNotificationResponse()
@@ -1739,7 +1799,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ParseNotification", params)
+            headers = request.headers
+            body = self.call("ParseNotification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ParseNotificationResponse()
@@ -1760,7 +1821,7 @@ class MpsClient(AbstractClient):
     def ProcessLiveStream(self, request):
         """对直播流媒体发起处理任务，功能包括：
 
-        * 智能内容审核（画面鉴黄、鉴政、鉴暴、声音鉴黄）；
+        * 智能内容审核（画面鉴黄、敏感信息检测、声音鉴黄）；
         * 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
 
         直播流处理事件通知实时写入用户指定的消息队列 CMQ 中，用户需要从消息队列 CMQ 中获取事件通知结果，同时处理过程中存在输出文件的，会写入用户指定的输出文件的目标存储中。
@@ -1772,7 +1833,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ProcessLiveStream", params)
+            headers = request.headers
+            body = self.call("ProcessLiveStream", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ProcessLiveStreamResponse()
@@ -1798,7 +1860,7 @@ class MpsClient(AbstractClient):
         4. 对视频采样截图；
         5. 对视频截图雪碧图；
         6. 对视频转自适应码流；
-        7. 智能内容审核（鉴黄、鉴恐、鉴政）；
+        7. 智能内容审核（鉴黄、敏感信息检测）；
         8. 智能内容分析（标签、分类、封面、按帧标签）；
         9. 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
 
@@ -1809,7 +1871,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ProcessMedia", params)
+            headers = request.headers
+            body = self.call("ProcessMedia", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ProcessMediaResponse()
@@ -1827,6 +1890,35 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RecognizeMediaForZhiXue(self, request):
+        """智能媒体识别，包含表情和动作识别。仅用于智学，其他调用无效。
+
+        :param request: Request instance for RecognizeMediaForZhiXue.
+        :type request: :class:`tencentcloud.mps.v20190612.models.RecognizeMediaForZhiXueRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.RecognizeMediaForZhiXueResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecognizeMediaForZhiXue", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RecognizeMediaForZhiXueResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ResetWorkflow(self, request):
         """重新设置一个已经存在且处于禁用状态的工作流。
 
@@ -1837,7 +1929,8 @@ class MpsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetWorkflow", params)
+            headers = request.headers
+            body = self.call("ResetWorkflow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetWorkflowResponse()
